slepc-3.18.0 2022-10-01
Report Typos and Errors

# MatCreateVecsEmpty

Get vector(s) compatible with the matrix, i.e. with the same parallel layout, but without internal array.

### Synopsis

    #include "slepcsys.h"
    PetscErrorCode MatCreateVecsEmpty(Mat mat,Vec *right,Vec *left)

Collective on mat

### Input Parameter

| mat | - the matrix

### Output Parameters

| right | - (optional) vector that the matrix can be multiplied against
| left | - (optional) vector that the matrix vector product can be stored in

### Note

This is similar to MatCreateVecs(), but the new vectors do not have an internal array, so the intended usage is with VecPlaceArray().

### See Also

VecDuplicateEmpty()

### Level

developer

### Location

src/sys/mat/matutil.c
Index of all sys routines
Table of Contents for all manual pages
Index of all manual pages